@@ -1,4 +1,3 @@
-import re
 from typing import Generic, TypeVar
 
 import fastapi
@@ -6,7 +5,7 @@ import orjson
 import pydantic
 import pydantic.generics
 
-snake_regexp = re.compile(r'_([a-z])')
+from souswift_core.utils import string
 
 
 def _orjson_dumps(val, *, default=None):
@@ -18,17 +17,15 @@ class Model(pydantic.BaseModel):
         allow_population_by_field_name = True
         json_loads = orjson.loads
         json_dumps = _orjson_dumps
+        frozen = True
 
         @classmethod
         def alias_generator(cls, field: str):
-            if field == 'id_':
-                return 'id'
-            return re.sub(snake_regexp, lambda match: match[1].upper(), field)
+            return string.to_camel(field.removesuffix('_'))
 
 
 class FrozenModel(Model):
-    class Config(Model.Config):
-        allow_mutation = False
+    """Same as Model, just for compatibility"""
 
 
 T = TypeVar('T', bound=Model)
